@@ -16,14 +16,15 @@
  *
  * \note Dialog sets up a Qt::WA_DeleteOnClose attribute so it's delete itself on close.
  */
-class SvnCleanupDialog : public QDialog {
+class SvnCleanupDialog : public QDialog
+{
     Q_OBJECT
 public:
     /**
      * \param[in] workingDir Directory to call 'svn cleanup' on.
      * \param[in,out] parent Parent widget.
      */
-    SvnCleanupDialog(const QString& workingDir, QWidget *parent = nullptr);
+    SvnCleanupDialog(const QString &workingDir, QWidget *parent = nullptr);
     virtual ~SvnCleanupDialog() override;
 
 public Q_SLOTS:
@@ -34,15 +35,15 @@ Q_SIGNALS:
     /**
      * Is emitted if an error occuers with a message \a msg.
      */
-    void errorMessage(const QString& msg);
+    void errorMessage(const QString &msg);
 
     /**
      * Is emitted for successful operation with a message \a msg.
      */
-    void operationCompletedMessage(const QString& msg);
+    void operationCompletedMessage(const QString &msg);
 
 private:
     Ui::SvnCleanupDialog m_ui;
 };
 
-#endif  // SVNCLEANUPDIALOG_H
+#endif // SVNCLEANUPDIALOG_H
